@@ -26,13 +26,13 @@
 `getLevels` <- function(data) {
     data <- as.data.frame(data)
     colnames <- paste("V", ncol(data), sep = ".")
-    pN <- unlist(lapply(data, possibleNumeric))
+    pN <- sapply(data, possibleNumeric)
     noflevels <- rep(NA, ncol(data))
     ulevels <- rep(NA, ncol(data))
     noflevels[pN] <- apply(
         data[, pN, drop = FALSE],
         2,
-        max
+        function(x) max(as.numeric(x))
     ) + 1
     ulevels <- apply(
         data,
@@ -48,7 +48,7 @@
         apply(
             data[, pN, drop = FALSE],
             2,
-            function(x) any(x %% 1 > 0)
+            function(x) any(as.numeric(x) %% 1 > 0)
         )
     ] <- 2
     if (any(factor | declared)) {
